import React from "react";
import { Link } from "@components/Link";
import {
  LogoTwitter,
  LogoLinkedin,
  Email,
  LogoInstagram,
  LogoFacebook,
  LogoXing,
  LogoMastodon
} from "@carbon/icons-react";

interface Props {
  name: string;
  position: string;
  organization?: string;
  image: string;
  email?: string;
  linkedin?: string;
  twitter?: string;
  instagram?: string;
  facebook?: string;
  mastodon?: string;
  xing?: string;
  className?: string;
}

const Member: React.FC<Props> = ({
  name,
  position,
  organization,
  image,
  email,
  linkedin,
  twitter,
  instagram,
  facebook,
  mastodon,
  xing,
  className,
}) => {
  return (
    <div
      className={`flex flex-1 flex-col items-center justify-between not-prose w-auto overflow-hidden ${
        className || ""
      }`}
    >
      <div className="aspect-square max-w-[160px] sm:max-w-[200px] md:max-w-[220px]">
        <div className="w-full h-full rounded-full overflow-hidden">
          <img className="w-full h-full object-cover" src={image} alt={name} />
        </div>
      </div>
      <div className="flex-1 flex flex-col justify-between">
        <h4 className="mt-6 font-plex text-lg leading-6 font-medium text-grey-900 text-center">
          {name}
        </h4>
        <p className="mt-1 break-words font-plex text-lg leading-6 font-normal text-green-500 text-center">
          {position}
        </p>
        {organization && (
          <p className="mt-1 break-words font-plex text-lg leading-6 font-normal text-green-500 text-center">
            {organization}
          </p>
        )}
        {(email || linkedin || twitter) && (
          <div className="mt-1.5 sm:mt-1 flex justify-center gap-2">
            {email && (
              <Link to={`mailto:${email.replace("@", "[ätt]")}`}>
                <Email
                  size={24}
                  className="text-grey-400 hover:text-grey-900"
                />
              </Link>
            )}
            {twitter && (
              <Link to={twitter} target="_blank" rel="noopener">
                <LogoTwitter
                  size={24}
                  className="text-grey-400 hover:text-grey-900"
                />
              </Link>
            )}
            {linkedin && (
              <Link to={linkedin} target="_blank" rel="noopener">
                <LogoLinkedin
                  size={24}
                  className="text-grey-400 hover:text-grey-900"
                />
              </Link>
            )}
            {instagram && (
              <Link to={instagram} target="_blank" rel="noopener">
                <LogoInstagram
                  size={24}
                  className="text-grey-400 hover:text-grey-900"
                />
              </Link>
            )}
            {facebook && (
              <Link to={facebook} target="_blank" rel="noopener">
                <LogoFacebook
                  size={24}
                  className="text-grey-400 hover:text-grey-900"
                />
              </Link>
            )}
            {mastodon && (
              <Link to={mastodon} target="_blank" rel="noopener">
                <LogoMastodon size={24} className="w-full h-full text-grey-400 hover:text-grey-900" />
              </Link>
            )}
            {xing && (
              <Link to={xing} target="_blank" rel="noopener">
                <LogoXing size={24} className="w-full h-full text-grey-400 hover:text-grey-900" />
              </Link>
            )}
          </div>
        )}
      </div>
    </div>
  );
};


export default Member;
