import React from "react";
import { Pill } from "@components/Pill";
import { Link } from "@components/Link";
import { INewsImage, INewsCategory } from "@interfaces/INews";
type PillColor = "dark" | "white";

interface Props {
  name: string;
  category: string;
  image: INewsImage;
  tag: INewsCategory;
  href: string;
  type: "light" | "dark";
  className?: string;
}

export const MiniCard: React.FC<Props> = ({
  name,
  image,
  category,
  tag,
  href,
  type,
  className = "",
}) => {
  const PILL_COLOR_MAPPING: Record<string, PillColor> = {
    dark: "white",
    light: "dark",
  };
  return (
    <div
      className={`flex bg-grey-100 w-fit md:max-w-screen-md h-[75px] md:h-[180px] ${className}`}
    >
      <div className="h-full">
        <Link to={href} className="block h-full aspect-square">
          <img className="w-full h-full" alt={image.alt} src={image.src} />
        </Link>
      </div>
      <div className="flex-col px-2 py-1 md:px-8 md:py-4 w-full h-full">
        <Link to={href}>
          <h1 className="font-karla text-base md:text-3xl md:leading-8 font-bold text-grey-900 md:mb-6 line-clamp-2">
            {name}
          </h1>
        </Link>
        <h2 className="text-sm font-plex font-normal text-grey-500 mb-2">
          {category}
        </h2>
        <div className="hidden md:flex flex-wrap">
          <Pill
            type={PILL_COLOR_MAPPING[type]}
            size="sm"
            rounded
            href={tag.href}
            title={tag.title}
          />
        </div>
      </div>
    </div>
  );
};
