import React, { useState, useEffect } from "react";
import { IToolbar, IToolbarItem } from "@interfaces/IHeader";
import { Link } from "@components/Link";
import useMediaQuery from "@hooks/useMediaQuery";

const Toolbar: React.FC<IToolbar> = ({
  isMobileOpen,
  className = "",
  items,
  extendedToolbarItems,
}) => {
  const isMobileOrTabletize = useMediaQuery("(max-width: 1024px)");
  const [shouldDisableFadingFx, setShouldDisableFadingFx] = useState(false);
  const [shouldFadeOthers, setShouldFadeOthers] = useState(false);

  useEffect(() => {
    setShouldDisableFadingFx(isMobileOrTabletize);
  }, [isMobileOrTabletize]);

  return (
    <div
      className={`${
        extendedToolbarItems
          ? "container px-5"
          : "lg:w-3/4 xl:w-fit px-9 hidden lg:block"
      } sm:border-x border-y transition-all ease-in-out duration-500 sm:bg-white select-none ${
        isMobileOpen
          ? "block border-white !bg-transparent"
          : "border-black hidden lg:block"
      } ${className}`}
    >
      <div className="w-full flex justify-center sm:justify-between items-center py-3 sm:py-5">
        <div className={`w-full ${extendedToolbarItems ? "lg:w-auto" : ""}`}>
          <ul
            className={`w-full flex justify-between uppercase sm:normal-case items-center ${
              isMobileOpen ? "text-white" : "text-grey-900"
            }`}
          >
            {items.map((item, index) => (
              <ToolbarItem
                key={index}
                {...item}
                faded={shouldFadeOthers}
                onHover={(value) =>
                  !shouldDisableFadingFx && setShouldFadeOthers(value)
                }
                className={index !== 0 ? "sm:ml-10" : ""}
              />
            ))}
          </ul>
        </div>
        {extendedToolbarItems && (
          <div className="hidden lg:block">
            <ul className="flex opacity-20">
              {extendedToolbarItems.map((item, index) => (
                <li
                  key={index}
                  className={`${
                    index !== extendedToolbarItems.length - 1
                      ? "mr-6 xl:mr-4"
                      : ""
                  } cursor-pointer`}
                >
                  <Link to={item.target}>{item.icon}</Link>
                </li>
              ))}
            </ul>
          </div>
        )}
      </div>
    </div>
  );
};

const ToolbarItem: React.FC<IToolbarItem> = ({
  title,
  icon,
  target,
  onlyDesktop,
  className = "",
  faded,
  onHover,
}) => {
  const classes = `text-sm sm:text-base leading-5 sm:leading-6 font-semibold sm:font-medium tracking-wider sm:tracking-normal transition-all ease-in duration-100 lg:hover:text-grey-900 ${className}`;
  return (
    <li
      onMouseEnter={() => onHover && onHover(true)}
      onMouseLeave={() => onHover && onHover(false)}
      className={`${classes} ${onlyDesktop ? "hidden lg:block" : ""} ${
        faded ? "text-grey-400" : "lg:text-grey-900"
      }`}
    >
      <Link to={target} className="flex flex-col sm:flex-row items-center">
        {icon}
        <span>{title}</span>
      </Link>
    </li>
  );
};

export default Toolbar;
