import * as React from "react";
import { Pill } from "@components/Pill";
import { DotMark, Close } from "@carbon/icons-react";
import type { Story } from "@ladle/react";

interface PillConfigProps {
  text: string;
  type:
    | "success"
    | "danger"
    | "warning"
    | "info"
    | "dark"
    | "default"
    | "purple"
    | "pink"
    | "white";
  rounded: boolean;
  size: "sm" | "lg";
}

export const PillStory: Story<PillConfigProps> = ({
  text,
  type,
  rounded,
  size,
}: PillConfigProps) => {
  return (
    <div className="container py-5">
      <div className="flex flex-wrap gap-2 sm:gap-7">
        <Pill
          type={type}
          size={size}
          title={text}
          rounded={rounded}
          onClick={() => alert("Pill clicked")}
        />
        <Pill
          size={size}
          title={text}
          rounded={rounded}
          onClick={() => alert("Pill clicked")}
          customBgColor="orange"
        />
        <Pill
          size={size}
          title={text}
          rounded={rounded}
          onClick={() => alert("Pill clicked")}
          customBgColor="pink"
        />
        <Pill
          type={type}
          size={size}
          title={text}
          rounded={rounded}
          icon={<DotMark className="w-3 h-3" />}
          onIconClick={() => alert("Icon Clicked")}
        />
        <Pill
          type={type}
          size={size}
          title={text}
          rounded={rounded}
          icon={<Close className="w-4 h-4" />}
          iconRight
          onIconClick={() => alert("Icon Clicked")}
        />
      </div>
    </div>
  );
};

PillStory.args = {
  text: "My Pill",
  rounded: true,
};

PillStory.argTypes = {
  type: {
    options: [
      "success",
      "danger",
      "warning",
      "info",
      "dark",
      "default",
      "purple",
      "pink",
      "white",
      "custom",
    ],
    control: { type: "select" },
    defaultValue: "success",
  },
  size: {
    options: ["sm", "lg"],
    control: { type: "radio" },
    defaultValue: "lg",
  },
};

export default {
  title: "Atoms",
};

PillStory.storyName = "Pill";
