import * as React from "react";
import HeroBox from "@components/HeroBox";
import { HeroSection } from "@components/HeroSection";
import type { Story } from "@ladle/react";

interface HeroBoxConfigProps {
  title: string;
  description: string;
  selfAligned: "left" | "right" | "center";
  transparentOnMobile: boolean;
  target?: string;
}

const DATA = {
  title: "Alles auf einer Karte: Die Hamburger Maker-Map",
  description:
    "Finde Fab Labs, offene Werkstätten, Handwerksbetriebe, Bildungs- und Veranstaltungsorte",
  categories: [
    {
      id: 1,
      title: "Fab City HH",
      href: "/",
    },
    {
      id: 2,
      title: "Makerspaces",
      href: "/",
    },
  ],
};

export const HeroBoxStory: Story<HeroBoxConfigProps> = ({
  title,
  description,
  selfAligned,
  transparentOnMobile,
  target,
}: HeroBoxConfigProps) => (
  <HeroSection
    src="https://picsum.photos/id/1015/1600/900"
    withGradientOnMobile={transparentOnMobile}
    imageTag="@Copyright"
  >
    <HeroBox
      title={title}
      description={description}
      categories={DATA.categories}
      selfAligned={selfAligned}
      transparentOnMobile={transparentOnMobile}
      target={target}
    />
  </HeroSection>
);

HeroBoxStory.args = {
  title: "Alles auf einer Karte: Die Hamburger Maker-Map",
  description:
    "Finde Fab Labs, offene Werkstätten, Handwerksbetriebe, Bildungs- und Veranstaltungsorte",
  transparentOnMobile: true,
  target: "https://www.google.com",
};

HeroBoxStory.argTypes = {
  selfAligned: {
    options: ["left", "right", "center"],
    control: { type: "radio" },
    defaultValue: "left",
  },
};

export default {
  title: "Molecules",
};

HeroBoxStory.storyName = "Hero box";
